write_dataset

Function write_dataset 

pub fn write_dataset(
    df: &mut DataFrame,
    output_path: &Path,
    metadata: BTreeMap<PlSmallStr, PlSmallStr>,
) -> Result<(), Error>
Write a DataFrame plus file-level metadata to output_path.

Format is selected from the output path extension: .parquet writes Apache Parquet with the metadata stored as footer key-value pairs; anything else (including .arrow/.ipc) writes Arrow IPC with the metadata stored as custom schema metadata.