pub fn validate_bboxes(
original: &CocoDataset,
restored: &CocoDataset,
) -> BboxValidationResultExpand description
Validate bounding boxes between two datasets using Hungarian matching.
pub fn validate_bboxes(
original: &CocoDataset,
restored: &CocoDataset,
) -> BboxValidationResultValidate bounding boxes between two datasets using Hungarian matching.